@@ -1,8 +1,9 @@
-package PGXN::Site::Locale::en v0.7.0;
+package PGXN::Site::Locale::en;
 
-use 5.12.0;
+use 5.10.0;
 use utf8;
 use parent 'PGXN::Site::Locale';
+our $VERSION = v0.7.1;
 
 our %Lexicon = (
 );
